@@ -1,12 +1,10 @@
 package Apache::HeavyCGI::ExePlan;
 use Apache::HeavyCGI; # want only the instance_of method
 use strict;
-use fields qw(PLAN);
-use constant FUNCTIONAL => 1; # If true, makes the method calls
-                              # subroutine calls. Seems to be slightly
-                              # faster.
+use fields qw(PLAN DEBUG FUNCTIONAL);
+
 use vars '%FIELDS', '$VERSION';
-$VERSION = sprintf "%d.%03d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/;
+$VERSION = sprintf "%d.%03d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/;
 
 # no singleton, every Application can have its own execution plan even
 # every object can have it's own, although, it probably doesn't pay
@@ -15,6 +13,8 @@ sub new {
   my($me,%arg) = @_;
   my $methods = $arg{METHODS} || [qw(header parameter)];
   my $classes = $arg{CLASSES} || [];
+  my $functional = $arg{FUNCTIONAL} || 0; #### undocumented
+  my $debug   = $arg{DEBUG} || 0; #### undocumented
   my @plan;
   for my $method (@$methods) {
     for my $class (@$classes) {
@@ -24,7 +24,7 @@ sub new {
 	$obj = Apache::HeavyCGI->instance_of($class);
       }
       next unless $subr = $obj->can($method);
-      if (FUNCTIONAL) {
+      if ($functional) {
 	push @plan, $subr, $obj;
       } else {
 	push @plan, $obj, $method;
@@ -34,6 +34,8 @@ sub new {
   no strict "refs";
   my $self = bless [\%{"$me\::FIELDS"}], $me;
   $self->{PLAN} = [ @plan ];
+  $self->{FUNCTIONAL} = $functional;
+  $self->{DEBUG} = $debug;
   $self;
 }
 
@@ -41,7 +43,8 @@ sub walk {
   my Apache::HeavyCGI::ExePlan $self = shift;
   my Apache::HeavyCGI $application = shift;
   for (my $i=0;;$i+=2) {
-    if (FUNCTIONAL) {
+    warn sprintf "entering i[$i]" if $self->{DEBUG} && $self->{DEBUG} & 1;
+    if ($self->{FUNCTIONAL}) {
       my $subr = $self->{PLAN}[$i] or last;
       my $obj = $self->{PLAN}[$i+1];
       $subr->($obj,$application);
@@ -50,6 +53,7 @@ sub walk {
       my $method = $self->{PLAN}[$i+1];
       $obj->$method($application);
     }
+    warn sprintf "exiting i[$i]" if $self->{DEBUG} && $self->{DEBUG} & 2;
   }
 }
 
@@ -68,6 +72,7 @@ Apache::HeavyCGI::ExePlan - Creates an execution plan for Apache::HeavyCGI
  my $plan = Apache::HeavyCGI::ExePlan->new(
     METHODS => ["header", "parameter"],
     CLASSES => ["my_application::foo", "my_application::bar", ... ]
+    DEBUG    => 1
  );
 
  $plan->walk;
@@ -75,9 +80,10 @@ Apache::HeavyCGI::ExePlan - Creates an execution plan for Apache::HeavyCGI
 =head1 DESCRIPTION
 
 When an execution plan object is instantiated, it immediately visits
-all specified classes, collects the singletons objects for these
-classes, and checks if the classes define the specified methods.
-It creates an array of objects and methods.
+all specified classes, collects the singleton objects for these
+classes, and checks if the classes define the specified methods. It
+creates an array of objects and methods or an array of code
+references.
 
 The walk method walks through the execution plan in the stored order
 and sends each singleton object the appropriate method and passes the
